@@ -474,12 +474,6 @@ ccchh_dooris_desktop_widget_on_timeout (gpointer data)
   
 	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_timeout()");
 
-	// stop event when offline
-	// connection event starts the timer again
-	if (!self->connected) {
-		return FALSE;
-	}
-
 // TODO: glib locking?
 // update() must be called only once at a time
 if (self->updating) {
@@ -488,6 +482,13 @@ if (self->updating) {
 }
 self->updating = TRUE;
 
+	// stop event when offline
+	// connection event starts the timer again
+	if (!self->connected) {
+self->updating = FALSE;
+		return FALSE;
+	}
+
 	// update internal state
 	if (!update(self)) {
 self->updating = FALSE;
@@ -624,7 +625,9 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 
 	// libconic signalled a connection state change
 
-	if (con_ic_connection_event_get_status(event) == CON_IC_STATUS_CONNECTED) {
+	ConIcConnectionStatus status = con_ic_connection_event_get_status(event);
+
+	if (status == CON_IC_STATUS_CONNECTED) {
 
 		// we are online now
 		self->connected = TRUE;
@@ -635,13 +638,22 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 
 		// force redraw to remove disconnection overlay
 		force_redraw(self);
-
-	} else {
+	} else if (status == CON_IC_STATUS_DISCONNECTED) {
 
 		// we are offline now
 		self->connected = FALSE;
 		// g_debug("ccchh-dooris-widget: new connection state: offline");
 
+//const gchar *iap_id = con_ic_event_get_iap_id(CON_IC_EVENT(event));
+//const gchar *bearer = con_ic_event_get_bearer_type(CON_IC_EVENT(event));
+//gchar *text = g_strdup_printf("
+// // g_debug("Hey, we are connected to IAP %s with bearer %s!", iap_id, bearer);
+// error = con_ic_connection_event_get_error(event);
+//hildon_banner_show_information_with_markup (GTK_WIDGET (self),
+//	NULL, /* icon_name - ignored */
+//	text);
+//g_free (text);
+
 		// don't stop timer here
 		// it will deactivate itsef if !connected
 		// frequent stop/start would prevent it from firing
@@ -651,6 +663,9 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 		// force redraw to add disconnection overlay
 		force_redraw(self);
 	}
+
+	// don't do anything on CON_IC_STATUS_DISCONNECTING
+	// or CON_IC_STATUS_NETWORK_UP
 }
 
 
